@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.secretmanager_v1.types import resources
@@ -75,14 +75,14 @@ class ListSecretsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[service.ListSecretsResponse]:
+    def pages(self) -> Iterator[service.ListSecretsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[resources.Secret]:
+    def __iter__(self) -> Iterator[resources.Secret]:
         for page in self.pages:
             yield from page.secrets
 
@@ -137,14 +137,14 @@ class ListSecretsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[service.ListSecretsResponse]:
+    async def pages(self) -> AsyncIterator[service.ListSecretsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[resources.Secret]:
+    def __aiter__(self) -> AsyncIterator[resources.Secret]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.secrets:
@@ -203,14 +203,14 @@ class ListSecretVersionsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[service.ListSecretVersionsResponse]:
+    def pages(self) -> Iterator[service.ListSecretVersionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[resources.SecretVersion]:
+    def __iter__(self) -> Iterator[resources.SecretVersion]:
         for page in self.pages:
             yield from page.versions
 
@@ -265,14 +265,14 @@ class ListSecretVersionsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[service.ListSecretVersionsResponse]:
+    async def pages(self) -> AsyncIterator[service.ListSecretVersionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[resources.SecretVersion]:
+    def __aiter__(self) -> AsyncIterator[resources.SecretVersion]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.versions:
