@@ -685,5 +685,8 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
             )
         return self._stubs["test_iam_permissions"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("SecretManagerServiceGrpcTransport",)
